@@ -2,14 +2,13 @@ import numpy as np
 from waver.datasets import run_and_visualize
 
 # Define a simulation, 12.8mm, 100um spacing
-speed = np.random.random((128, 128)) * 343 + 343
 sim_params = {
     'size': (12.8e-3, 12.8e-3),
     'spacing': 100e-6,
     'duration': 80e-6,
     'min_speed': 343,
     'max_speed': 686,
-    'speed': speed,
+    'speed': 343,
     'time_step': 50e-9,
     'temporal_downsample': 2,
     'sources': [{
